summaryrefslogtreecommitdiff
path: root/sys/arch/vax/qbus
diff options
context:
space:
mode:
authorBrad Smith <brad@cvs.openbsd.org>2005-11-24 04:52:27 +0000
committerBrad Smith <brad@cvs.openbsd.org>2005-11-24 04:52:27 +0000
commit8299929082286fef62323c4cedd8d0f514d52d57 (patch)
treec99aa80e02f930da78c7fcf344dce3a789f11d9f /sys/arch/vax/qbus
parentf97381f6397a58ad7c9eeb3b2a1afc3f58cb613a (diff)
splimp -> splvm
ok martin@
Diffstat (limited to 'sys/arch/vax/qbus')
-rw-r--r--sys/arch/vax/qbus/uba.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/arch/vax/qbus/uba.c b/sys/arch/vax/qbus/uba.c
index f459348ed14..2e2a37c0d02 100644
--- a/sys/arch/vax/qbus/uba.c
+++ b/sys/arch/vax/qbus/uba.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: uba.c,v 1.10 2004/07/07 23:10:46 deraadt Exp $ */
+/* $OpenBSD: uba.c,v 1.11 2005/11/24 04:52:26 brad Exp $ */
/* $NetBSD: uba.c,v 1.57 2001/04/26 19:16:07 ragge Exp $ */
/*
* Copyright (c) 1996 Jonathan Stone.
@@ -76,7 +76,7 @@ uba_enqueue(struct uba_unit *uu)
uh = (void *)((struct device *)(uu->uu_softc))->dv_parent;
- s = splimp();
+ s = splvm();
SIMPLEQ_INSERT_TAIL(&uh->uh_resq, uu, uu_resq);
splx(s);
}
@@ -85,7 +85,7 @@ uba_enqueue(struct uba_unit *uu)
* When a routine that uses resources is finished, the next device
* in queue for map registers etc is called. If it succeeds to get
* resources, call next, and next, and next...
* This routine must be called at splimp.
*/
void
uba_done(struct uba_softc *uh)
@@ -193,7 +193,7 @@ ubareset(struct uba_softc *uh)
struct uba_reset *ur;
int s;
- s = splimp();
+ s = splvm();
SIMPLEQ_INIT(&uh->uh_resq);
printf("%s: reset", uh->uh_dev.dv_xname);
(*uh->uh_ubainit)(uh);
@@ -85,7 +85,7 @@ uba_enqueue(struct uba_unit *uu)
* in queue for map registers etc is called. If it succeeds to get
* resources, call next, and next, and next...
- * This routine must be called at splimp.
+ * This routine must be called at splvm.
*/
void